package kieker.webgui.beans;

import java.util.ArrayList;
import java.util.List;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import javax.faces.context.FacesContext;

import kieker.analysis.model.analysisMetaModel.MIProject;
import kieker.analysis.model.analysisMetaModel.impl.MAnalysisMetaModelFactory;
import kieker.webgui.common.FileManager;

import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

/**
 * This bean can be used to handle all available projects within the program.
 * 
 * @author Nils Christian Ehmke
 */
@ManagedBean
@ApplicationScoped
public class AvailableProjectsBean {

	private final List<MIProject> projects;
	private final MAnalysisMetaModelFactory factory;

	public AvailableProjectsBean() {
		projects = FileManager.getInstance().loadAllProjects();
		factory = new MAnalysisMetaModelFactory();
	}

	public synchronized boolean addProject(final String projectName) {
		/* Create a new project. */
		final MIProject project = factory.createProject();
		project.setName(projectName);

		/* Try to save the project. */
		if (!FileManager.getInstance().saveNewProject(project)) {
			return false;
		} else {

			/* Set the new project as the main project, if the current user doesn't have one. */
			FacesContext context = FacesContext.getCurrentInstance();
			SelectedProjectBean bean = (SelectedProjectBean) context.getApplication().evaluateExpressionGet(context, "#{selectedProjectBean}",
					SelectedProjectBean.class);
			if (bean.getMainProject() == null) {
				bean.setMainProject(project);
			}

			return projects.add(project);
		}
	}

	@SuppressWarnings(value = { "unused" })
	public synchronized TreeNode getProjectsRoot() {
		TreeNode root = new DefaultTreeNode("Root", null);

		for (final MIProject project : projects) {
			final TreeNode projectNode = new DefaultTreeNode("project", project, root);
			final TreeNode dependenciesNode = new DefaultTreeNode("dependencies", "Dependencies", projectNode);
			final TreeNode usedPluginsNode = new DefaultTreeNode("usedPlugins", "Used Plugins", projectNode);
		}

		return root;
	}
}
